<?php /* Smarty version 2.6.20, created on 2009-01-26 14:55:32
         compiled from return.tpl */ ?>
<?php $_smarty_tpl_vars = $this->_tpl_vars;
$this->_smarty_include(array('smarty_include_tpl_file' => "DTD.tpl", 'smarty_include_vars' => array()));
$this->_tpl_vars = $_smarty_tpl_vars;
unset($_smarty_tpl_vars);
 ?>
<body>
<!--全体-->
<div id="wrapper">

	<?php $_smarty_tpl_vars = $this->_tpl_vars;
$this->_smarty_include(array('smarty_include_tpl_file' => "header.tpl", 'smarty_include_vars' => array()));
$this->_tpl_vars = $_smarty_tpl_vars;
unset($_smarty_tpl_vars);
 ?>
		<div id="content">
<!--パンくずリスト-->
		<div id="point">　<a href="index.html">TOP</a>&gt;返却</div>
        <!--メイン画面-->
	  <div id="main">
	  <div id="center">
	    <p align="center">【<?php echo $this->_tpl_vars['book_name']; ?>
の返却を確認致しました】</p>
	    <p align="center">ご利用ありがとうございました。</p>
	    <p align="center"><a href="index.php?reset=yes">TOPへ戻る</a></p>
	  </div>
	  </div>
	</div>
	<div id="footer"></div>
</div>
<!--著作権表記-->
<div id="cpyright">
	Copyright &copy;DENSETU, 2008 All rights reserved.
</div>

</body>
</html>
